package com.ruoyi.system.service.impl;

import java.util.Map;
import java.util.HashMap;
import java.util.stream.Collector;
import java.util.stream.Collectors;
import java.util.function.Function;
import com.ruoyi.system.domain.SnServerTemplate;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.system.api.model.LoginUser;
import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.common.core.utils.ServletUtils;
import java.util.List;
import com.ruoyi.system.domain.SnTemplate;
import com.ruoyi.common.security.service.TokenService;
import com.ruoyi.system.mapper.SnServerTemplateMapper;
import org.springframework.beans.factory.annotation.Autowired;
import com.ruoyi.system.mapper.SnTemplateMapper;
import org.springframework.stereotype.Service;
import com.ruoyi.system.service.ISnTemplateService;

@Service
public class SnTemplateServiceImpl implements ISnTemplateService
{
    @Autowired
    private SnTemplateMapper snTemplateMapper;
    @Autowired
    private SnServerTemplateMapper snServerTemplateMapper;
    @Autowired
    private TokenService tokenService;
    
    public SnTemplate selectSnTemplateByTemplateId(final Long templateId) {
        return this.snTemplateMapper.selectSnTemplateByTemplateId(templateId);
    }
    
    public List<SnTemplate> selectSnTemplateList(final SnTemplate snTemplate) {
        snTemplate.setIsDelete(Integer.valueOf(0));
        return this.snTemplateMapper.selectSnTemplateList(snTemplate);
    }
    
    public int insertSnTemplate(final SnTemplate snTemplate) {
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        snTemplate.setIsDelete(Integer.valueOf(0));
        snTemplate.setCreateId(loginUser.getUserid());
        snTemplate.setCreateName(loginUser.getUsername());
        snTemplate.setCreateTime(DateUtils.getNowDate());
        snTemplate.setAgentId(Long.valueOf(Long.parseLong(loginUser.getSysUser().getCreateBy())));
        snTemplate.setAgentName(loginUser.getSysUser().getCreateName());
        return this.snTemplateMapper.insertSnTemplate(snTemplate);
    }
    
    public int updateSnTemplate(final SnTemplate snTemplate) {
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        snTemplate.setUpdateId(loginUser.getUserid());
        snTemplate.setUpdateName(loginUser.getUsername());
        snTemplate.setUpdateTime(DateUtils.getNowDate());
        return this.snTemplateMapper.updateSnTemplate(snTemplate);
    }
    
    public AjaxResult deleteSnTemplateByTemplateIds(final Long[] templateIds) {
        final SnServerTemplate param = new SnServerTemplate();
        param.getParams().put("serverTemplateIds", templateIds);
        param.setIsDelete(Integer.valueOf(0));
        final List<SnServerTemplate> templates = this.snServerTemplateMapper.selectSnServerTemplateList(param);
        if (!templates.isEmpty()) {
            final String ips = templates.stream().map((Function<? super Object, ?>)SnServerTemplate::getServerIp).collect((Collector<? super Object, ?, String>)Collectors.joining(" , "));
            return AjaxResult.error("服务器【" + ips + "】正在使用模板，不能删除");
        }
        final int num = this.snTemplateMapper.deleteSnTemplateByTemplateIds(templateIds);
        return AjaxResult.success((Object)num);
    }
    
    public AjaxResult countryNum() {
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        Long userId = null;
        if (!loginUser.getRoles().contains("admin") && !loginUser.getRoles().contains("super")) {
            userId = loginUser.getUserid();
        }
        final List<Map<String, Object>> list = this.snTemplateMapper.countryNum(userId);
        final Map<String, Long> map = new HashMap<String, Long>();
        list.forEach(tmp -> map.put(tmp.get("country"), tmp.get("count")));
        return AjaxResult.success((Object)map);
    }
}
